==> haskell-descriptive-0.9.4-48-i686.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-CNweVIbhQXCDbvGRpoRBta
key: descriptive-0.9.4-CNweVIbhQXCDbvGRpoRBta
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
abi: 52887a152da15f4b7f700485ad9af92a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-CNweVIbhQXCDbvGRpoRBta
depends:
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ base-4.9.0.0
    bifunctors-5.4.2-89Yr6mDv1GYKyj9AXEUlAj containers-0.5.7.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.4-52-i686.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-9ll6XjPEs8YHWwoSRSTjso
key: descriptive-0.9.4-9ll6XjPEs8YHWwoSRSTjso
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
abi: 6d7acb672294ef7f76121396ad59f96b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-9ll6XjPEs8YHWwoSRSTjso
depends:
    aeson-1.1.2.0-6MVvUcgiXyL5LInpwFqRIH base-4.9.0.0
    bifunctors-5.4.2-89Yr6mDv1GYKyj9AXEUlAj containers-0.5.7.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.15-GEIRVwGBHHyElVCNt38fm3
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
